<?php
/**
* Joomla plugin: IR GeoData
* Development: alexey@gnevyshev.ru
*/
defined( '_JEXEC' ) or die;

if (!defined('DS')) define('DS', DIRECTORY_SEPARATOR);

// for debug
if (!function_exists('console_log')) {
    function console_log($something, $label = '')
    {
        $doc = JFactory::getDocument();
        if (!empty($label)) $doc->addScriptDeclaration('console.log("'.(string) $label.':");');
        $doc->addScriptDeclaration('console.log('.json_encode($something).');');
    }
}

class plgSystemIrGeoData extends Jplugin
{
    public function __construct(& $subject, $config)
    {
        parent::__construct($subject, $config);
        $this->loadLanguage();
    }
	
	public function onAfterInitialise()
	{
        $app = JFactory::getApplication();
        
        // set constants
        $ip = $_SERVER['REMOTE_ADDR'];
        if (!empty($ip) && $app->isSite()) {
            
            // get geo data
            // first, try from session
            $session = JFactory::getSession();
            $geodata = $session->get('geodata', array(), 'ir_geodata');
            
            // for test
            // $session->clear('geodata', 'ir_geodata'); $geodata = $session->get('geodata', array(), 'ir_geodata');
            
            console_log($geodata, 'Geodata from session');
            
            // next, try from DB
            if (empty($geodata)) {
                
                require_once __DIR__.DS.'helper_site.php';
                
                $db_save_period = $this->params->get('db_save_period', 0, 'int');
                $last_db_clear = $this->params->get('last_db_clear', '', 'string');
                
                // first let's clear old records
                if (strtotime($last_db_clear) < (time() - 24*3600)) {
                    irgd_deleteOldRecords($db_save_period); // delete records
                    irgd_updateParamLastDbClear(); // update plugin params
                }
                
                $geodata = irgd_getGeoDataFromDb($ip);
                console_log($geodata, 'Geodata from Database');
                
                // add to session
                if (!empty($geodata)) {
                    $session->set('geodata', $geodata, 'ir_geodata');
                }
            }
            
            // for test
            // $session->clear('geodata', 'ir_geodata'); $geodata = $session->get('geodata', array(), 'ir_geodata');
            
            // next, try from Sypex Geo
            if (empty($geodata)) {
                
                $geodata = irgd_getGeoDataFromSypex($ip);
                console_log($geodata, 'Geodata from Sypex Geo');
                
                if (!empty($geodata)) {
                    $session->set('geodata', $geodata, 'ir_geodata'); // write to session
                    irgd_writeGeoDataForIp($geodata, $ip); // write to DB
                }
            }
            
            // set constants
            if (!empty($geodata)) {
                foreach ($geodata as $key => $value) {
                    if (!defined('GEODATA_'.strtoupper($key))) define('GEODATA_'.strtoupper($key), $value);
                }
            }
        }
        
        if ($app->isAdmin()) {
            require_once __DIR__.DS.'helper_admin.php';
            $check_sypex_geo = $this->params->get('check_sypex_geo', 0, 'int');
            $download_link = $this->params->get('download_link', '', 'string');
            $frequency_check_update = $this->params->get('frequency_check_update', 15, 'int');
            irgd_checkSypexData($check_sypex_geo, $download_link, $frequency_check_update);
        }
    }
    
	public function onAfterRender()
	{
	    $app = JFactory::getApplication();
        if ($app->isSite()) {
            $replace_constants = $this->params->get('replace_constants', 0, 'int');
            if ($replace_constants) {
                // $time = microtime(true);
                require_once __DIR__.DS.'helper_site.php';
                $replace_result = irgd_replaceConstants();
                // $time = round((microtime(true) - $time), 4); echo $time;
            }
        }
	}
}